@@ -35,7 +35,8 @@ def test_ref_parse_filename():
     parser = ReferenceParser()
     assert(parser.parse_filename("issue.54.md").item_type == "issue")
     assert(parser.parse_filename("issue.54.md").number == 54)
-    assert(parser.parse_filename("issue.54.md").as_tuple() == ("issue", 54, ()))
+    assert(parser.parse_filename("issue.54.md").as_tuple()
+           == ("issue", 54, ()))
     assert(parser.parse_filename("issue.54.gh.md").as_tuple()
            == ("issue", 54, ("gh",)))
     assert(parser.parse_filename("issue.54") is None)
@@ -59,7 +60,8 @@ def test_fragment():
     fragment = Fragment(fn, io=fragmentio)
     assert(str(fragment.filename) == fn)
     assert(len(fragment.refs) == 1)
-    fragment.parse_file()
+    extras = fragment.parse_file()
+    assert(not extras)
     assert("content" in fragment.text)
     assert("---" not in fragment.text)
 
@@ -83,7 +85,8 @@ def test_fragment_with_error():
     fragmentio = StringIO(FRAGMENT_ERROR)
     fragment = Fragment(fn, io=fragmentio)
     try:
-        fragment.parse_file()
+        extras = fragment.parse_file()
+        assert(not extras)
     except RuntimeError as e:
         assert("Could not parse line" in str(e))
         return
@@ -100,7 +103,8 @@ def test_simple_fragment():
     fragment = Fragment(fn, io=fragmentio)
     assert(str(fragment.filename) == fn)
     assert(len(fragment.refs) == 1)
-    fragment.parse_file()
+    extras = fragment.parse_file()
+    assert(not extras)
     assert(len(fragment.refs) == 1)
     assert("content" in fragment.text)
 
@@ -128,7 +132,8 @@ def test_fragment_prefix_size_limit():
     fragment = Fragment(fn, io=fragmentio)
     # Haven't parsed the text yet
     assert(fragment.prefix == '')
-    fragment.parse_file()
+    extras = fragment.parse_file()
+    assert(not extras)
     assert(fragment.prefix == 'This')
 
 
@@ -138,7 +143,8 @@ def test_fragment_with_comment():
     fragment = Fragment(fn, io=fragmentio)
     assert(str(fragment.filename) == fn)
     assert(len(fragment.refs) == 1)
-    fragment.parse_file()
+    extras = fragment.parse_file()
+    assert(not extras)
     # skips comments
     assert(len(fragment.refs) == 4)
     assert("---" not in fragment.text)
@@ -146,6 +152,63 @@ def test_fragment_with_comment():
     print(fragment.refs)
 
 
+FRAGMENT_WITH_BULLET = """---
+- issue.55
+- mr.23
+pr.25
+issue.54
+---
+- This is content.
+"""
+
+
+def test_fragment_strip_bullet():
+    fn = "issue.54.md"
+    fragmentio = StringIO(FRAGMENT_WITH_BULLET)
+    fragment = Fragment(fn, io=fragmentio)
+    assert(str(fragment.filename) == fn)
+    assert(len(fragment.refs) == 1)
+    extras = fragment.parse_file()
+    assert(not extras)
+    # skips comments
+    assert(len(fragment.refs) == 4)
+    assert("---" not in fragment.text)
+    assert("- " not in fragment.text)
+
+
+FRAGMENT_WITH_BULLETS = """---
+- issue.55
+- mr.23
+pr.25
+issue.54
+---
+- This is content.
+- This is second.
+"""
+
+
+def test_fragment_split_on_bullets():
+    fn = "issue.54.md"
+    fragmentio = StringIO(FRAGMENT_WITH_BULLETS)
+    fragment = Fragment(fn, io=fragmentio)
+    assert(str(fragment.filename) == fn)
+    assert(len(fragment.refs) == 1)
+    extras = fragment.parse_file()
+    # skips comments
+    assert(len(fragment.refs) == 4)
+    assert("---" not in fragment.text)
+    assert("- " not in fragment.text)
+    assert("second" not in fragment.text)
+    assert(len(extras) == 1)
+
+    frag2 = extras[0]
+    assert("second" in frag2.text)
+    assert(len(frag2.refs) == 4)
+    assert("---" not in frag2.text)
+    assert("- " not in frag2.text)
+    assert("content" not in frag2.text)
+
+
 PREFIX_DATA = (
     ("mr.1544.md", "Document new thing"),
     ("mr.1729.md", "Make generation of event explicit"),
